# Command line interface

Command Line Interface (CLI) for OpenHydroponics

`hypo` provides a way to interact with the OpenHydroponics network via the command line.
It allows users to execute various commands and pass arguments to perform specific tasks.

```{eval-rst}
.. click:: openhydroponics.cli:cli
   :prog: hypo
   :nested: full
```
